@@ -1,13 +1,6 @@
-from lzsr.lzsr.lzsr_math.lzsr_series import (
-    Isochromatic,
-    Proportional,
-    Fibonacci,
-    Catalan,
-    special,
-    function
-)
-from lzsr.lzsr.lzsr_password.lasr_lock import lock
-from lzsr.lzsr.lzsr_password.lzsr_key import key
+import lzsr.lzsr.lzsr_series
+import lzsr.lzsr.lzsr_lock
+import lzsr.lzsr.lzsr_key
 
 __all__ =[
     'Isochromatic_Firstitem','Isochromatic_Lastitem','Isochromatic_tolerance','Isochromatic_Numberofitems',
@@ -24,4 +17,4 @@ __all__ =[
     'key','keys'
 ]
 
-__version__ = '1.8.7'
+__version__ = '1.8.9'
